==> webpdf-wsclient-9.0.0-sources.jar: net/webpdf/wsclient/schema/operation/ConverterPageType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p729701_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:p909447_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Sets the page size, margins, and headers and footers for the converted document in the PDF document.&lt;/p&gt;
 * </pre>
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p729701_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:p909447_="https://jakarta.ee/xml/ns/jaxb" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&lt;b&gt;Important:&lt;/b&gt;&#13;
 *                     The settings may override the default values for a format that itself has page settings.&#13;
 *                     In addition, not all settings can be applied to all formats (see, for example, the description of headers and footers).&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for ConverterPageType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ConverterPageType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}PageType">
 *       <all>
 *         <element name="header" type="{http://schema.webpdf.de/1.0/operation}ConverterHeaderType" minOccurs="0"/>
 *         <element name="footer" type="{http://schema.webpdf.de/1.0/operation}ConverterFooterType" minOccurs="0"/>
 *       </all>
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterPageType", propOrder = {
    "header",
    "footer"
})
public class ConverterPageType
    extends PageType
{

    protected ConverterHeaderType header;
    protected ConverterFooterType footer;

    /**
     * Gets the value of the header property.
     * 
     * @return
     *     possible object is
     *     {@link ConverterHeaderType }
     *     
     */
    public ConverterHeaderType getHeader() {
        return header;
    }

    /**
     * Sets the value of the header property.
     * 
     * @param value
     *     allowed object is
     *     {@link ConverterHeaderType }
     *     
     */
    public void setHeader(ConverterHeaderType value) {
        this.header = value;
    }

    public boolean isSetHeader() {
        return (this.header!= null);
    }

    /**
     * Gets the value of the footer property.
     * 
     * @return
     *     possible object is
     *     {@link ConverterFooterType }
     *     
     */
    public ConverterFooterType getFooter() {
        return footer;
    }

    /**
     * Sets the value of the footer property.
     * 
     * @param value
     *     allowed object is
     *     {@link ConverterFooterType }
     *     
     */
    public void setFooter(ConverterFooterType value) {
        this.footer = value;
    }

    public boolean isSetFooter() {
        return (this.footer!= null);
    }

}

==> webpdf-wsclient-9.0.1-sources.jar: net/webpdf/wsclient/schema/operation/ConverterPageType.java <==

package net.webpdf.wsclient.schema.operation;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlType;


/**
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p383362_="https://jakarta.ee/xml/ns/jaxb" xmlns:p837822_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;Sets the page size, margins, and headers and footers for the converted document in the PDF document.&lt;/p&gt;
 * </pre>
 * 
 * <pre>
 * &lt;?xml version="1.0" encoding="UTF-8"?&gt;&lt;p xmlns:p383362_="https://jakarta.ee/xml/ns/jaxb" xmlns:p837822_="http://jaxb2-commons.dev.java.net/basic/inheritance" xmlns:tns="http://schema.webpdf.de/1.0/operation" xmlns:xs="http://www.w3.org/2001/XMLSchema"&gt;&lt;b&gt;Important:&lt;/b&gt;&#13;
 *                     The settings may override the default values for a format that itself has page settings.&#13;
 *                     In addition, not all settings can be applied to all formats (see, for example, the description of headers and footers).&lt;/p&gt;
 * </pre>
 * 
 * 
 * <p>Java class for ConverterPageType complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType name="ConverterPageType">
 *   <complexContent>
 *     <extension base="{http://schema.webpdf.de/1.0/operation}PageType">
 *       <all>
 *         <element name="header" type="{http://schema.webpdf.de/1.0/operation}ConverterHeaderType" minOccurs="0"/>
 *         <element name="footer" type="{http://schema.webpdf.de/1.0/operation}ConverterFooterType" minOccurs="0"/>
 *       </all>
 *     </extension>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "ConverterPageType", propOrder = {
    "header",
    "footer"
})
public class ConverterPageType
    extends PageType
{

    protected ConverterHeaderType header;
    protected ConverterFooterType footer;

    /**
     * Gets the value of the header property.
     * 
     * @return
     *     possible object is
     *     {@link ConverterHeaderType }
     *     
     */
    public ConverterHeaderType getHeader() {
        return header;
    }

    /**
     * Sets the value of the header property.
     * 
     * @param value
     *     allowed object is
     *     {@link ConverterHeaderType }
     *     
     */
    public void setHeader(ConverterHeaderType value) {
        this.header = value;
    }

    public boolean isSetHeader() {
        return (this.header!= null);
    }

    /**
     * Gets the value of the footer property.
     * 
     * @return
     *     possible object is
     *     {@link ConverterFooterType }
     *     
     */
    public ConverterFooterType getFooter() {
        return footer;
    }

    /**
     * Sets the value of the footer property.
     * 
     * @param value
     *     allowed object is
     *     {@link ConverterFooterType }
     *     
     */
    public void setFooter(ConverterFooterType value) {
        this.footer = value;
    }

    public boolean isSetFooter() {
        return (this.footer!= null);
    }

}
